==> browser_detect-8.x-1.0.tar.gz: browser_detect/js/browser_detect.js <==
(function (Drupal, $) {
  'use strict';

  Drupal.behaviors.browser_detect = {
    browserVersion: function () {
      const userBrowser = (navigator.userAgent).toLowerCase();
      let browsers = [],
        systemOp = [],
        matches;

      // Browser
      browsers.safari = userBrowser.indexOf('safari');
      browsers.chrome = userBrowser.indexOf('chrome');
      browsers.firefox = userBrowser.indexOf('firefox');
      browsers.ie = userBrowser.indexOf('msie');
      browsers.ie11 = userBrowser.indexOf('rv:11');
      browsers.msedge = userBrowser.indexOf('edge');

      //SO
      systemOp.linux = userBrowser.indexOf('linux');
      systemOp.macintosh = userBrowser.indexOf('macintosh');
      systemOp.windows = userBrowser.indexOf('windows');
      systemOp.ipad = userBrowser.indexOf('ipad');
      systemOp.android = userBrowser.indexOf('android');
      systemOp.iphone = userBrowser.indexOf('iphone');

      //Chrome, Safari or Edge className
      if ((browsers.safari > -1) && (browsers.chrome <= -1) && (browsers.msedge <= -1)) {
        document.getElementsByTagName('html')[0].className += ' safari';
        matches = userBrowser.match(/version\/([0-9]*)/);
        document.getElementsByTagName('html')[0].className += ' safari' + matches[1];
      } else if ((browsers.chrome > -1) && (browsers.msedge <= -1)) {
        document.getElementsByTagName('html')[0].className += ' chrome';
        matches = userBrowser.match(/chrome\/([0-9]*)/);
        document.getElementsByTagName('html')[0].className += ' chrome' + matches[1];
      } else if (browsers.msedge > -1) {
        document.getElementsByTagName('html')[0].className += ' edge';
        matches = userBrowser.match(/edge\/([0-9]*)/);
        document.getElementsByTagName('html')[0].className += ' edge' + matches[1];
      }
      //firefox
      if (browsers.firefox > -1) {
        document.getElementsByTagName('html')[0].className += ' firefox';
        matches = userBrowser.match(/firefox\/([0-9]*)/);
        document.getElementsByTagName('html')[0].className += ' firefox' + matches[1];
      }
      //IE
      if (browsers.ie > -1 || browsers.ie11 > -1) {
        document.getElementsByTagName('html')[0].className += ' ie';
        if (browsers.ie > -1) {
          matches = userBrowser.match(/msie\ ([0-9]*)/);
          document.getElementsByTagName('html')[0].className += ' ie' + matches[1];
        } else {
          //IE11
          document.getElementsByTagName('html')[0].className += ' ie11';
        }
      }

      //Windows
      if (systemOp.windows > -1) {
        document.getElementsByTagName('html')[0].className += ' windows desktop';
      }
      //macintosh
      if (systemOp.macintosh > -1) {
        document.getElementsByTagName('html')[0].className += ' macintosh desktop';
      }
      //linux
      if (systemOp.linux > -1 && systemOp.android <= -1) {
        document.getElementsByTagName('html')[0].className += ' linux desktop';
      }
      //android
      if (systemOp.android > -1) {
        document.getElementsByTagName('html')[0].className += ' android mobile';
      }
      //ipad
      if (systemOp.ipad > -1) {
        document.getElementsByTagName('html')[0].className += ' ios ipad mobile';
      }
      //iphone
      if (systemOp.iphone > -1) {
        document.getElementsByTagName('html')[0].className += ' ios iphone mobile';
      }
    },

    attach: function (context) {
      const hasHtmlTag = $('html', context).length;
      if (hasHtmlTag) {
        Drupal.behaviors.browser_detect.browserVersion();
      }
    }
  };

})(Drupal, jQuery);

==> browser_detect-8.x-1.2.tar.gz: browser_detect/js/browser_detect.js <==
(function (Drupal, $) {
  'use strict';

  Drupal.behaviors.browser_detect = {
    browserVersion: function () {
      const userBrowser = (navigator.userAgent).toLowerCase();
      let browsers = [],
        systemOp = [],
        matches;

      // Browser
      browsers.safari = userBrowser.indexOf('safari');
      browsers.chrome = (userBrowser.indexOf('chrome') > -1 || userBrowser.indexOf('crios') > -1 ) ? 1 : -1;
      browsers.firefox = userBrowser.indexOf('firefox');
      browsers.ie = userBrowser.indexOf('msie');
      browsers.ie11 = userBrowser.indexOf('rv:11');
      browsers.msedge = userBrowser.indexOf('edg');
      browsers.samsung = userBrowser.indexOf('samsung');
      browsers.ucbrowser = userBrowser.indexOf('ucbrowser');
      browsers.facebook = (userBrowser.indexOf('fbdv') > -1 || userBrowser.indexOf('fb_iab') > -1 ) ? 1 : -1;
      browsers.instagram = userBrowser.indexOf('instagram');

      //SO
      systemOp.linux = userBrowser.indexOf('linux');
      systemOp.macintosh = userBrowser.indexOf('macintosh');
      systemOp.windows = userBrowser.indexOf('windows');
      systemOp.ipad = userBrowser.indexOf('ipad');
      systemOp.android = userBrowser.indexOf('android');
      systemOp.iphone = userBrowser.indexOf('iphone');

      //Chrome, Safari, Edge, Samsung, UC, Facebook & Instagram className
      if(browsers.samsung > -1) {
        document.getElementsByTagName('html')[0].className += ' samsungbrowser';
      } else if(browsers.ucbrowser > -1) {
        document.getElementsByTagName('html')[0].className += ' ucbrowser';
      } else if(browsers.facebook > -1) {
        document.getElementsByTagName('html')[0].className += ' facebook';
      } else if(browsers.instagram > -1) {
        document.getElementsByTagName('html')[0].className += ' instagram';
      } else if ((browsers.safari > -1) && (browsers.chrome <= -1) && (browsers.msedge <= -1)) {
        document.getElementsByTagName('html')[0].className += ' safari';
        matches = userBrowser.match(/version\/([0-9]*)/);
        document.getElementsByTagName('html')[0].className += ' safari' + matches[1];
      } else if ((browsers.chrome > -1) && (browsers.msedge <= -1)) {
        document.getElementsByTagName('html')[0].className += ' chrome';
        matches = userBrowser.match(/chrome\/([0-9]*)|crios\/([0-9]*)/);
        document.getElementsByTagName('html')[0].className += ' chrome' + matches[1];
      } else if (browsers.msedge > -1) {
        document.getElementsByTagName('html')[0].className += ' edge';
        matches = userBrowser.match(/edge\/([0-9]*)|edg\/([0-9]*)/);
        document.getElementsByTagName('html')[0].className += ' edge' + matches[1];
      }

      //firefox
      if (browsers.firefox > -1) {
        document.getElementsByTagName('html')[0].className += ' firefox';
        matches = userBrowser.match(/firefox\/([0-9]*)/);
        document.getElementsByTagName('html')[0].className += ' firefox' + matches[1];
      }

      //IE
      if (browsers.ie > -1 || browsers.ie11 > -1) {
        document.getElementsByTagName('html')[0].className += ' ie';
        if (browsers.ie > -1) {
          matches = userBrowser.match(/msie\ ([0-9]*)/);
          document.getElementsByTagName('html')[0].className += ' ie' + matches[1];
        } else {
          //IE11
          document.getElementsByTagName('html')[0].className += ' ie11';
        }
      }

      //Windows
      if (systemOp.windows > -1) {
        document.getElementsByTagName('html')[0].className += ' windows desktop';
      }
      //macintosh
      if (systemOp.macintosh > -1) {
        document.getElementsByTagName('html')[0].className += ' macintosh desktop';
      }
      //linux
      if (systemOp.linux > -1 && systemOp.android <= -1) {
        document.getElementsByTagName('html')[0].className += ' linux desktop';
      }
      //android
      if (systemOp.android > -1) {
        document.getElementsByTagName('html')[0].className += ' android mobile';
      }
      //ipad
      if (systemOp.ipad > -1) {
        document.getElementsByTagName('html')[0].className += ' ios ipad mobile';
      }
      //iphone
      if (systemOp.iphone > -1) {
        document.getElementsByTagName('html')[0].className += ' ios iphone mobile';
      }
    },

    attach: function (context) {
      const hasHtmlTag = $('html', context).length;
      if (hasHtmlTag) {
        Drupal.behaviors.browser_detect.browserVersion();
      }
    }
  };

})(Drupal, jQuery);
